@@ -16,7 +16,7 @@ class Analysis
         void run();
 
     private:
-        void alterOptions(Parser::OptionsVect const &specs);
+        void actualize(Parser::OptionsVect const &specs);
         void requireBase() const;
 };
 
