@@ -2,9 +2,11 @@
 #include "densities.ih"
 
 Densities::Densities()
+:
+    d_base{ "BreastDensities:", "ageGroup:" }
 {
                                 // retrieve the Densities: ageGroup: lines
-    auto lines = Parser::any({ "BreastDensities:", "ageGroup:" });
+    auto lines = Parser::any(d_base);
 
     bool checkRange = true;     // check whether age ranges connect.
 
