@@ -4,13 +4,12 @@
 void Densities::writeParameters(std::ostream &out) const
 {
     out << 
-        "   densities:\n";
+        "BreastDensities:\n";
+
+    Globals::setPrecision(out, 2);
 
     for (Density const &density: d_densities)
-    {
-        density.insertInto(out);
-        out.put('\n');
-    }
+        out << "  " << density << '\n';
 
     out.put('\n');
 }
