@@ -1,61 +1,67 @@
 #ifndef INCLUDED_INCIDENCE_
 #define INCLUDED_INCIDENCE_
 
-// #                            lifeTimeRisk      same: meanAge  stdandardDev
-// #               carier       ---------------------   
-// #               name    prob value  spread   dist.     
-// tumorIncidence: Normal  1    0.226  0.0053   Normal    
-// tumorIncidence: BRCA1   0    0.96   -        -         
-// tumorIncidence: BRCA2   0    0.96   -        -         
-// 
-//  conform the original sources: with 0 probabilities the specified values
+//  Incidence:
+//      Normal:
+//          prob:   1
+//          #                   value   spread  distr.                    
+//          lifetimeRisk:         .226  .0053   Normal  
+//          meanAge:            72.9    .552    Normal 
+//          stdDev:             21.1
+//
+//      BRCA1:
+//          prob:   0
+//          #                   value   spread  distr.                    
+//          lifetimeRisk:         .96
+//          meanAge:            53.9
+//          stdDev:             16.51
+//
+//      BRCA2:
+//          prob:   0
+//          #                   value   spread  distr.                    
+//          lifetimeRisk:         .96
+//          meanAge:            53.9
+//          stdDev:             16.51
+
+//  as in the original sources: with 0 probabilities the specified values
 //  are set to 0
 
 
 #include <vector>
 #include <string>
 
-#include "../typedefs/typedefs.h"
 #include "../vsd/vsd.h"
-#include "../scenario/scenario.h"
 
-struct Incidence: public Spread
+struct Incidence
 {
-    Scenario const &d_scenario;
-
     class Params
     {
         friend class Incidence;
 
-        uint16_t d_idx;
-        double   d_prob;
+        double   d_prob = 0;
+        double  d_stdDev = 0;   // std dev.
 
-        VSD     d_risk;           // lifeTimeRisk
-        VSD     d_mean;
-        VSD     d_stdDev;
+        VSD     d_vsd[2];       // lifetimeRisk and meanAge
 
         public:
-            uint16_t idx() const;
+            void vary();
+
             double   prob() const;
-    
             VSD const &risk() const;           // lifeTimeRisk
             VSD const &mean() const;
-            VSD const &stdDev() const;
+            double stdDev() const;
     };
 
     private:
         std::vector<Params> d_params;
-
-        double d_cumProb[END_CARRIERS];
-
+        DoubleVect d_cumProb;
         DoubleVect2 d_tumorRisk;
-
-        static Map s_carrier;    
-        static char const s_id[];
+        static StringVect s_carrier;    
 
     public:
-        Incidence(Scenario const &scenario);
-        void refresh();
+        Incidence();
+
+        void vary();                            // vary d_vsd's values
 
         std::vector<Params> const &params() const;  
         uint16_t carrier() const;               // randomly selected carrier
@@ -67,13 +73,13 @@ struct Incidence: public Spread
         void writeParameters(std::ostream &out) const;
 
     private:
-        void set();
+        void setCarrier(size_t idx);            // sets d_params
+        bool carrierProb(StringVect const &base, Params &params);
+        static bool lifetimeRisk(StringVect &base, VSD &vsd);
+        static bool meanAge(StringVect &base, VSD &vsd);
+        static bool stdDev(StringVect &base, double &sd);
 
-        bool addProbabilities(double *sumProb, Scenario::Range const &range);
-
-                                                // negative return value:
-                                                // specification error
-        double add(Scenario::const_iterator const &info);
+        double sumProbs();
 
         void setTumorRisk();            // assign values to d_tumorRisk    1
         void setTumorRisk(DoubleVect &ageValues,                        // 2
@@ -90,11 +96,6 @@ inline std::vector<Incidence::Params> const &Incidence::params() const
     return d_params;
 }
 
-inline uint16_t Incidence::Params::idx() const
-{
-    return d_idx;
-}
-
 inline double Incidence::Params::prob() const
 {
     return d_prob;
@@ -102,15 +103,15 @@ inline double Incidence::Params::prob() const
 
 inline VSD  const &Incidence::Params::risk() const
 {
-    return d_risk;
+    return d_vsd[0];
 }
 
 inline VSD const &Incidence::Params::mean() const
 {
-    return d_mean;
+    return d_vsd[1];
 }
 
-inline VSD const &Incidence::Params::stdDev() const
+inline double Incidence::Params::stdDev() const
 {
     return d_stdDev;
 }
