@@ -6,14 +6,14 @@
 void Incidence::setTumorRisk(DoubleVect &ageValues, Params const &params)
 {
     size_t age = 0;
-    double stdDev = params.stdDev().value();
     double mean = params.mean().value();
 
-    double factor1 = params.risk().value() / (stdDev * s_sqrt2PI);
+    double factor1 = params.risk().value() / 
+                                (params.stdDev() * Globals::s_sqrt2PI);
 
-    for (double &value: ageValues)
+    for (double &value: ageValues)          // compute the risks per age value
     {
-        double factor2 = (age++ - mean) / stdDev;
+        double factor2 = (age++ - mean) / params.stdDev();
         value = factor1 * exp(-(factor2 * factor2 / 2));
     }
 }
