@@ -11,13 +11,7 @@ void Loop::characteristics(Status natural, Status tumor)
         // treat the tumor: add the treatment cost and compute the age of
         // tumor-caused death. There is a tumor: no need to call
         // diameterCheck()
-double cost = d_costs.treatment(d_tumor.age(), d_tumor.diameter()); 
-xerr("costs: " << cost << ", age: " << d_tumor.age() << ", dia: " << \
-d_tumor.diameter());
-
-d_caseCost += cost;
-
-//    d_caseCost += d_costs.treatment(d_tumor.age(), d_tumor.diameter());
+    d_caseCost += d_costs.treatment(d_tumor.age(), d_tumor.diameter());
     d_tumor.setDeathAge();
 
     if (d_naturalDeathAge < d_tumor.deathAge())     // naturally caused death
@@ -26,4 +20,8 @@ d_caseCost += cost;
         setStatus(tumor, d_tumor.deathAge());
 }
 
+// double cost = d_costs.treatment(d_tumor.age(), d_tumor.diameter()); 
+// xerr("costs: " << cost << ", age: " << d_tumor.age() << ", dia: " <<[bsl]
+// d_tumor.diameter());
+// d_caseCost += cost;
 
