@@ -5,7 +5,7 @@ void Loop::labels(ostream &out) const
 {
     out << "Analysis " << d_timestamp << '\n';
 
-    for (auto const &line: d_scenario.labels())
+    for (auto const &line: d_labels)
         out << line << '\n';
 
     out.put('\n');
