@@ -8,7 +8,7 @@
 
 void Loop::maybeFalsePositive(ModBase *modBase, double screeningAge)
 {
-    if (d_random.uniform() > modBase->specificity(screeningAge))
+    if (Random::instance().uniform() > modBase->specificity(screeningAge))
     {
         modBase->falsePositive();
         ++d_nRoundFP[d_round];
