@@ -5,11 +5,8 @@ void Loop::preScreen()
 {
     // see prescreen.txt
 
-    if (d_nRounds == 0)                     // no scenario rounds
+    if (d_nRounds == 0)         // no scenario rounds, no pre-screening
         return;
-
-//xerr("");
-
                                 // using the complement of the prescreen 
     if (                        // in the original code
         d_naturalDeathAge >= d_screening.age(0)
@@ -18,7 +15,7 @@ void Loop::preScreen()
     )
         return;
 
-xerr("active");
+        // pre-screening is performed:
 
     if (not d_tumor or (d_tumor and d_naturalDeathAge < d_tumor.age()))
         preTumorDeath();    // natural death: no tumor or not self-detected
