@@ -8,8 +8,8 @@ void Loop::screen(double screeningAge)
     // visit all modalities: for (ModBase *...) or comparable
 
                                             // org/screen: 4, screen.txt: 1
-    for (ModBase *modBase:
-                  d_modalities.use(d_screening.round(d_round).modalityIDs())
+    for (ModBase *modBase: d_modalities.use(
+                                d_screening.round(d_round).modalityIndices())
     )
     { 
         if (not use(modBase))
