@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "loop.ih"
 
 void Loop::setStatus(Status status, double age)
