@@ -10,7 +10,7 @@ Arg::LongOption g_longOpts[] =
     Arg::LongOption{"data",         'D'},
     Arg::LongOption{"death-age",    'a'},
     Arg::LongOption{"help",         'h'},
-    Arg::LongOption{"cases",        'c'},
+    Arg::LongOption{"last-case",    'l'},
     Arg::LongOption{"one-analysis", 'o'},
     Arg::LongOption{"parameters",   'P'},
     Arg::LongOption{"rounds",       'R'},
@@ -26,7 +26,7 @@ auto const *g_longEnd = g_longOpts + size(g_longOpts);
 int main(int argc, char **argv)
 try
 {
-    Arg const &arg = Arg::initialize("a:B:c:C:D:hoP:R:S:t:vV",
+    Arg const &arg = Arg::initialize("a:B:l:C:D:hoP:R:S:t:vV",
                                       g_longOpts, g_longEnd, argc, argv);
     arg.versionHelp(usage, Icmake::version, arg.option('o') ? 0 : 1);
 
