@@ -5,7 +5,7 @@ void Mammo::betaHandler()
 {
     d_base.back() = "beta:";
 
-    Parser::extract( Parser::one(d_base), d_beta, 5);
+    Parser::extract( Parser::one(d_base), d_beta, N_BETA);
 }
 
 
