@@ -12,12 +12,13 @@
 //
 //      #      bi-rad:  a       b       c       d             
 //      dose:           3       3       3       3  
+//      m:             .136    .136    .136    .136
 //
 //      #             ageGroup
 //      specificity:  0 - 40:  .961     40 - *: .965
 //
-//      #       1       2       3        4       m
-//      beta:  -4.38    .49     -1.34    -7.18   .136
+//      #       1       2       3        4    
+//      beta:  -4.38    .49     -1.34    -7.18
 //
 //      systematicError:  0.1
 
@@ -26,14 +27,20 @@ class Tumor;
 
 class Mammo: public ModBase
 {
+    enum BetaParams
+    {
+        N_BETA = 4
+    };
+
     Tumor const &d_tumor;
 
     StringVect d_base;
 
     double d_dose[N_BIRADS];
+    double d_m[N_BIRADS];
     SpecificityVect d_specVect;
 
-    double d_beta[5];               // 5th value is m
+    double d_beta[N_BETA];
     double d_sysErr;
 
     public:
@@ -44,8 +51,10 @@ class Mammo: public ModBase
         void doseHandler();
         void betaHandler();
         void setSystematicError();
+        void setM();
 
-        void insertBeta(std::ostream &out, size_t begin, size_t end) const;
+        void insertBeta(std::ostream &out) const;
+        void insertM(std::ostream &out) const;
 
         double const *vDose() const override;               // 1
         double vDose(uint16_t) const override;              // 2
