@@ -8,12 +8,13 @@
 //
 //      #      bi-rad:  a       b       c       d             
 //      dose:           3       3       3       3  
+//      m:             .136    .136    .136    .136
 //
 //      #             ageGroup
 //      specificity:  0 - 40:  .961     40 - *: .965
 //
-//      #       1      2   3      4      m
-//      beta:  -4.38  .49  -1.34  -7.18  .136 
+//      #       1      2   3      4      
+//      beta:  -4.38  .49  -1.34  -7.18  
 //
 //      #                default:
 //      # systematicError:  0.1 
@@ -26,6 +27,7 @@ Mammo::Mammo(Tumor const &tumor)
 {
     costHandler(d_base);                        // ModBase 
     doseHandler();
+    setM();
     specificityHandler(d_specVect, d_base);     // ModBase
     betaHandler();
     setSystematicError();
