@@ -1,15 +1,12 @@
-//#define XERR
+#define XERR
 #include "mammo.ih"
 
 void Mammo::vInsert(ostream &out) const
 {
     insertBirads(Globals::setPrecision(out, 1), "dose:     ", d_dose);
 
-    out << "    beta parameters:";
-
-    insertBeta(out, 0, 4);
-    out <<  "m: " << d_beta[4] << '\n';    // m value
-
+    insertM(out);
+    insertBeta(out);
     insertSpecificity(Globals::setPrecision(out, 3), 5, d_specVect);
 
     Globals::setPrecision(out, 2) << 
