@@ -9,7 +9,7 @@
 double Mammo::vSensitivity(size_t idx) const
 {
     double diameter = d_tumor.diameter();
-    double mValue = d_beta[4];
+    double mValue = d_m[idx];
 
     double expBeta = 
         exp(
