@@ -12,10 +12,10 @@
     
 double Mammo::vSpecificity(double age) const
 {
-    return find_if(d_spec.rbegin(), d_spec.rend(), 
+    return find_if(d_specVect.rbegin(), d_specVect.rend(), 
                     [&](Specificity const &spec)
                     {
-                        return spec.d_beginAge < age;
+                        return spec.beginAge() < age;
                     }
-            )->d_value;
+            )->value();
 }
