@@ -3,6 +3,6 @@
 
 void Modalities::resetCounters(size_t nRounds)
 {
-    for (ModBase *modBase: d_modBase)
-        modBase->resetCounters(nRounds);
+    for (auto modBasePtr: d_modBaseVect)
+        modBasePtr->resetCounters(nRounds);
 }
