@@ -3,10 +3,11 @@
 
 void Modalities::writeParameters(ostream &out) const
 {
-    out << "   modalities:\n";
+    out << "Modalities:\n"
+           "\n";
 
-    for (ModBase *modBase: d_modBase)
-        out << *modBase;
+    for (auto modBasePtr: d_modBaseVect)
+        out << *modBasePtr;
 
     out.put('\n');
 }
