@@ -1,13 +1,15 @@
 //#define XERR
 #include "modbase.ih"
 
+// static
 void ModBase::insertBirads(ostream &out, char const *label, 
                            double const *value)
 {
-    out << setw(12) << ' ' << "bi-rads " << label;
+    out << "    bi-rad " << label;
 
     for (size_t idx = 0; idx != N_BIRADS; ++idx)
-        out << (idx + 1) << ": " << setw(5) << value[idx] << ", ";
+        out << static_cast<char>('a' + idx) << ": " << setw(5) << 
+                                                        value[idx] << ", ";
 
     out.put('\n');
 }
