@@ -3,6 +3,7 @@
 
 ModBase::ModBase(std::string const &id)
 :
-    d_id(id),
-    d_nr(++s_nr)
+    d_id(id)
+//,
+//    d_nr(++s_nr)
 {}
