@@ -2,9 +2,8 @@
 #define INCLUDED_ROUND_
 
 #include <cmath>
+#include <iosfwd>
 #include <istream>
-#include <ostream>
-#include <vector>
 
     // contains a round specification from the config file
 
@@ -16,28 +15,41 @@ class Round
     friend std::ostream &operator<<(std::ostream &out, Round const &round);
 
     double d_age;
-    uint16_t d_idx;
-    StringVect d_modalities;
+    Uint16Vect d_modalities;        // modalities used in this screening round
+    StringVect const &d_modalityIDs;
 
     public:
+        Round(StringVect const &modalityIDs);
+
+        bool add(uint16_t idx);
+
         double age() const;
         uint16_t rndAge() const;                // rounded double age value
 
-                                                // modality IDs used by this
-        StringVect const &modalityIDs() const;  // screening round
-        uint16_t idx() const;
+                                                // modality indices used by 
+        Uint16Vect const &modalityIndices() const;  // this screening round
+
+//        StringVect const &modalityIDs() const;  // screening round
 
     private:
-        std::istream &extract(std::istream &in);
         std::ostream &insert(std::ostream &out) const;
 };
-    
 
-inline  StringVect const &Round::modalityIDs() const
+inline Round::Round(StringVect const &modalityIDs)
+:
+    d_modalityIDs(modalityIDs)
+{}
+    
+inline  Uint16Vect const &Round::modalityIndices() const
 {
     return d_modalities;
 }
 
+// inline  StringVect const &Round::modalityIDs() const
+// {
+//     return d_modalities;
+// }
+
 inline double Round::age() const
 {
     return d_age;
@@ -48,14 +60,10 @@ inline uint16_t Round::rndAge() const
     return round(d_age);
 }
 
-inline uint16_t Round::idx() const
-{
-    return d_idx;
-}
 
 inline std::istream &operator>>(std::istream &in, Round &round)
 {
-    return round.extract(in);
+    return in >> round.d_age;
 }
 
 inline std::ostream &operator<<(std::ostream &out, Round const &round)
