@@ -17,7 +17,7 @@ string Simulator::fileAnalysis()
             size_t pos = line.find_first_not_of(" \t\r");
                 pos != string::npos             // found non-blanks 
                 and                             // and 'analysis:' as 1st word
-                line.find("analysis:", pos) == pos
+                line.find("Analysis:", pos) == pos
         ) 
         {
             d_next = true;
