@@ -20,7 +20,7 @@ void Simulator::setAnalysisSource()
             size_t pos = line.find_first_not_of(" \t\r");
             if (pos == string::npos)
                 continue;
-            if (line.find("analysis:", pos) == pos) // analysis up to EOF of
+            if (line.find("Analysis:", pos) == pos) // analysis up to EOF of
             {
                 d_next = true;
                 break;                              // the next analysis
