@@ -10,14 +10,15 @@
 // #                   agegroup
 // Tomo specificity:   0 - 40:   0.961     40 - *: 0.965
 
-Tomo::Tomo(Scenario::Range &range)
+Tomo::Tomo()
 :
-    ModBase(s_ID)
+    ModBase("Tomo"),
+    d_base{ "Modalities:", "Tomo:", "" }
 {
-    uint16_t lineNr = configure(s_handlers, range, s_ID, &d_spec);
-
-    if (configured() != (COST | SENSITIVITY | SPECIFICITY | DOSE))
-        Error::msg(INCOMPLETE_SPEC, range.src, lineNr, s_ID);
+    costHandler(d_base);                // ModBase handles the costs spec.
+    doseHandler();
+    sensitivityHandler();
+    specificityHandler(d_specificity, d_base);
 }
 
 
