@@ -27,22 +27,22 @@ void Tumor::reset()
 
     Random &random = Random::instance();
 
-    d_pSurvival = random.uniform();
+    d_pSurvival = random.uniformCase();
 
-    d_startVolume = volume(d_growth.start().value());
+    d_startVolume = volume(d_growth.start());
 
-    d_doublingDays = random.logNormal(d_growth.group(idx).mean().value(),
-                                      d_growth.group(idx).stdDev().value());
+    AgeGroupVSD const &group = d_growth.ageGroupVSD(idx);
+    d_doublingDays = random.logNormal(group.mean().value(), group.stdDev());
 
     d_doublingYears = d_doublingDays / N_YEARDAYS;
 
     d_selfDetect = random.logNormal(d_growth.selfMu().value(), 
-                                    d_growth.selfSigma().value());
+                                    d_growth.selfSigma());
 
     d_prePeriod =   d_doublingDays *
                     log(
                         volume(d_selfDetect) / 
-                        volume(d_growth.start().value())
+                        volume(d_growth.start())
                     ) * s_log2YearInv;
 
     d_detectableAge = d_age - d_prePeriod;
