@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "tumor.ih"
 
     // this function computes the estimated death age using the function 
@@ -37,5 +37,4 @@ void Tumor::setDeathAge(double detectionAge)
     }
 
     d_deathAge = std::min(detectionAge + mid, 100.);
-    xerr(d_deathAge);
 }
