@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "tumor.ih"
 
 Tumor::Tumor(TumorInfo const &tumorInfo)
