@@ -1,4 +1,4 @@
-//#define XERR
+#define XERR
 #include "tumorinfo.ih"
 
     // see void calcTotalRisk(int carrierIndex)
@@ -11,6 +11,7 @@ void TumorInfo::cumTotalRisk(DoubleVect const &radiationRisk)
     uint16_t carrierIdx = d_incidence.carrier();
 
     auto iter = radiationRisk.begin();
+
     for (double risk: d_incidence.tumorRisk(carrierIdx))
         d_cumRisk.push_back(sum += risk * *iter++);
 }
