@@ -14,29 +14,20 @@ class Scenario;
 
 class TumorInfo: public Globals
 {
-//    uint16_t  d_induction;      // beir model to use
-
     Incidence d_incidence;
-
     Beir7     d_beir7;
     Growth    d_growth;
     Survival  d_survival;
 
     DoubleVect d_cumRisk;
 
-//    std::string const &d_totalriskFile;
-
-//    static char const s_id[];
-
     public:
-        TumorInfo(Scenario const &scenario);
-
-                                            // generate a spread on parameters 
-        void refresh(bool spread);          // if spread is true
+                                 
+        void vary();                            // vary parameters 
                                     
         Incidence const &incidence() const;
     
-        uint16_t  induction() const;      // beir model to use
+        uint16_t  induction() const;            // beir model to use
         Beir7     const &beir7() const;
         Growth    const &growth() const;
         Survival  const &survival() const;
