@@ -3,10 +3,10 @@
 
 void TumorInfo::writeParameters(ostream &out) const
 {
-    out << "   tumor:\n";
+    out << "Tumor:\n";
 
+    d_beir7.writeParameters(out);
     d_incidence.writeParameters(out);
     d_growth.writeParameters(out);
     d_survival.writeParameters(out);
-    d_beir7.writeParameters(out);
 }
